@@ -70,6 +70,7 @@ class FastAndSlow(FedAvg):
         r_slow: int = 1,
         t_fast: int = 10,
         t_slow: int = 10,
+        initial_parameters: Optional[Weights] = None,
     ) -> None:
         super().__init__(
             fraction_fit=fraction_fit,
@@ -80,6 +81,7 @@ class FastAndSlow(FedAvg):
             eval_fn=eval_fn,
             on_fit_config_fn=on_fit_config_fn,
             on_evaluate_config_fn=on_evaluate_config_fn,
+            initial_parameters=initial_parameters,
         )
         self.min_completion_rate_fit = min_completion_rate_fit
         self.min_completion_rate_evaluate = min_completion_rate_evaluate
